# tokyopopuchange
東京都の人口をを可視化できるPython Package。  
Python Package for visualization of population in tokyo.

## Example of use
```
pip install tokyopopuchange
python tokyopopuchange.py
```

## output
![image](https://i.imgur.com/1lf3JRC.png)
